@@ -1,4 +1,14 @@
-__version__ = '0.9.2'
+"""
+PyXNAT
+======
+
+pyxnat provides an API to access data on XNAT (see http://xnat.org)
+servers.
+
+Visit http://packages.python.org/pyxnat for more information.
+"""
+
+from .version import VERSION as __version__
 
 from .core import Interface
 from .core import SearchManager
