@@ -11,7 +11,7 @@ class EAttrs(object):
 
         Help to retrieve the attributes paths relevant to this element::
             >>> subject.attrs()
-            ['xnat:subjectData/sharing', 
+            ['xnat:subjectData/sharing',
              'xnat:subjectData/sharing/share',
              'xnat:subjectData/resources',
              ...
@@ -26,10 +26,10 @@ class EAttrs(object):
              >>> interface.manage.schemas.add('myschema/myschema.xsd')
     """
     def __init__(self, eobj):
-        """ 
+        """
             Parameters
             ----------
-            eobj: 
+            eobj:
                 :class:`EObject` Object
         """
         self._eobj = eobj
@@ -51,14 +51,14 @@ class EAttrs(object):
             self._datatype = self._eobj.datatype()
 
         return self._datatype
-    
+
     def _get_id(self):
         if self._id is None:
             self._id = self._eobj.id()
 
         return self._id
 
-    def set(self, path, value):
+    def set(self, path, value, **kwargs):
         """ Set an attribute.
 
             Parameters
@@ -75,13 +75,14 @@ class EAttrs(object):
                     standard representation for dates and times
                     established by the W3C.
         """
-        put_uri = self._eobj._uri+'?%s=%s' % (urllib.quote(path), 
-                                              urllib.quote(value)
+        put_uri = self._eobj._uri + '?xsiType=%s&%s=%s' % (urllib.quote(self._get_datatype())
+                                                         , urllib.quote(path)
+                                                         , urllib.quote(value)
                                               )
 
-        self._intf._exec(put_uri, 'PUT')
+        self._intf._exec(put_uri, 'PUT', **kwargs)
 
-    def mset(self, dict_attrs):
+    def mset(self, dict_attrs, **kwargs):
         """ Set multiple attributes at once.
 
             It is more efficient to use this method instead of
@@ -96,16 +97,16 @@ class EAttrs(object):
                 principles as the single `set()` method.
         """
 
-        query_str = '?' + '&'.join(['%s=%s' % (urllib.quote(path), 
+        query_str = '?xsiType=%s' % (urllib.quote(self._get_datatype())) + ''.join(['&%s=%s' % (urllib.quote(path),
                                                urllib.quote(val)
-                                               ) 
+                                               )
                                     for path, val in dict_attrs.items()
                                     ]
                                    )
 
         put_uri = self._eobj._uri + query_str
 
-        self._intf._exec(put_uri, 'PUT')
+        self._intf._exec(put_uri, 'PUT', **kwargs)
 
     def get(self, path):
         """ Get an attribute value.
@@ -132,7 +133,7 @@ class EAttrs(object):
         # unfortunately the return headers do not always have the
         # expected name
 
-        header = difflib.get_close_matches(path.split('/')[-1], 
+        header = difflib.get_close_matches(path.split('/')[-1],
                                            jdata.headers()
                                            )
         if header == []:
@@ -140,7 +141,11 @@ class EAttrs(object):
         else:
             header = header[0]
 
-        return jdata.get(header).replace('\s', ' ')
+        replaceSlashS = lambda x : x.replace('\s', ' ')
+        if type(jdata.get(header)) == list:
+            return map(replaceSlashS, jdata.get(header))
+        else:
+            return jdata.get(header).replace('\s', ' ')
 
     def mget(self, paths):
         """ Set multiple attributes at once.
@@ -169,11 +174,11 @@ class EAttrs(object):
 
         results = []
 
-        # unfortunately the return headers do not always have the 
+        # unfortunately the return headers do not always have the
         # expected name
 
         for path in paths:
-            header = difflib.get_close_matches(path.split('/')[-1], 
+            header = difflib.get_close_matches(path.split('/')[-1],
                                                jdata.headers())
 
             if header == []:
@@ -181,5 +186,5 @@ class EAttrs(object):
             else:
                 header = header[0]
             results.append(jdata.get(header).replace('\s', ' '))
-                
+
         return results
