@@ -8,7 +8,10 @@ import hashlib
 import re
 import time
 import shutil
-from StringIO import StringIO
+try:
+    from StringIO import StringIO
+except ImportError:
+    from io import StringIO
 
 
 _platform = platform.system()
@@ -19,20 +22,7 @@ DEBUG = False
 def md5name(key):
     """ Generates a unique path to store server responses.
     """
-
-    ext = re.findall('.*?(?=(\?format=.+?(?=\?|&|$)|'
-                     '\&format=.+?(?=\?|&|$)))', key)
-    
-    if ext != []:
-        last = key.split('?')[0].split('/')[-1]
-        key = key.replace(ext[0], '')
-        ext = ext[0].split('format')[1]
-        key += ext
-        last += ext
-    else:
-        last = key.split('/')[-1]
-
-    return '%s_%s' % (hashlib.md5(key).hexdigest(), last.replace('=', '.'))
+    return hashlib.md5(key).hexdigest()
 
 def bytes_to_human(size, unit):
     """ Returns a more human readable version of a size in bytes.
@@ -73,7 +63,7 @@ class HTCache(object):
                 The function used to generate the responses cache paths.
         """
         self._intf = interface
-        
+
         self.cache = cachedir
         self.safe = safe
 
@@ -86,7 +76,11 @@ class HTCache(object):
         retval = None
 
         _cachepath = os.path.join(self.cache, self.safe(key))
-        
+
+        if DEBUG:
+            print('cache get:', key,)
+            print('\n\t', _cachepath)
+
         try:
             f = file('%s.headers' % _cachepath, "rb")
             retval = f.read()
@@ -104,7 +98,7 @@ class HTCache(object):
                 f = file(_altpath, "rb")
                 retval += f.read()
                 f.close()
-            except IOError:
+            except:
                 return
 
         return retval
@@ -112,6 +106,7 @@ class HTCache(object):
     def set(self, key, value):
         """ Sets cache entry.
         """
+
         _fakepath = '%s.alt' % os.path.join(self.cache, self.safe(key))
         _headerpath = '%s.headers' % os.path.join(self.cache, self.safe(key))
         _cachepath = os.path.join(self.cache, self.safe(key))
@@ -124,13 +119,17 @@ class HTCache(object):
                 f = file(_fakepath, "rb")
                 _altpath = f.read()
                 f.close()
-                
+
                 if _altpath != self._cachepath and os.path.exists(_altpath):
                     # remove old custom file if different location
                     os.remove(_altpath)
 
             _cachepath = self._cachepath
 
+            if DEBUG:
+                print('cache set custom:', key)
+                print('\n\t', _cachepath)
+
             f = open(_fakepath, 'w')
             f.write(_cachepath)
             f.close()
@@ -142,12 +141,16 @@ class HTCache(object):
                 f = file(_fakepath, "rb")
                 _altpath = f.read()
                 f.close()
-                
+
                 if _altpath != self._cachepath and os.path.exists(_altpath):
                     os.remove(_altpath) # remove actual file
 
                 os.remove(_fakepath) # remove pointer file
 
+            if DEBUG:
+                print('cache set default:', key)
+                print('\n\t', _cachepath)
+
         header = ''
         value = StringIO(value)
 
@@ -155,8 +158,8 @@ class HTCache(object):
         if time.gmtime(time.time())[5] % 10 == 0:
             disk_status = self._intf.cache.disk_ready(_cachepath)
 
-            if not disk_status[0]:
-                print 'Warning: %s is %.2f%% full' % \
+            if not disk_status[0] and self._intf.cache._warn:
+                print('Warning: %s is %.2f%% full') % \
                     (os.path.dirname(_cachepath), disk_status[1])
 
         while len(header) < 4 or header[-4:] != '\r\n\r\n':
@@ -180,11 +183,16 @@ class HTCache(object):
                  into using something else than the default path to
                  store entries.
         """
-        self._cachepath = path
+        if self._intf._mode != 'offline':
+            self._cachepath = path
 
     def delete(self, key):
         """ Deletes the entry.
         """
+
+        if DEBUG:
+            print('cache del:', key)
+
         _cachepath = os.path.join(self.cache, self.safe(key))
         _fakepath = '%s.alt' % _cachepath
         _headerpath = '%s.headers' % _cachepath
@@ -204,14 +212,14 @@ class HTCache(object):
         if os.path.exists(_headerpath):
             os.remove(_headerpath)
 
-    def get_diskpath(self, key):
-        """ Gets the disk path where the entry is stored (default path 
+    def get_diskpath(self, key, force_default=False):
+        """ Gets the disk path where the entry is stored (default path
             or not)
         """
         _cachepath = os.path.join(self.cache, self.safe(key))
         _fakepath = '%s.alt' % _cachepath
 
-        if os.path.exists(_fakepath):
+        if os.path.exists(_fakepath) and not force_default:
             f = file(_fakepath, "rb")
             _altpath = f.read()
             f.close()
@@ -233,12 +241,16 @@ class CacheManager(object):
         """
             Parameters
             ----------
-            interface: 
+            interface:
                 :class:`Interface` Object
 
         """
         self._intf = interface
-        self._cache = interface._conn.cache
+        self._cache = interface._http.cache
+        self._warn = True
+
+    def enable_warnings(self, toggle=True):
+        self._warn = toggle
 
     def clear(self):
         """ Clears all files tracked by pyxnat.
@@ -247,7 +259,7 @@ class CacheManager(object):
             f = file(_fakepath, "rb")
             _altpath = f.read()
             f.close()
-            
+
             if os.path.exists(_altpath):
                 os.remove(_altpath)
 
@@ -296,8 +308,8 @@ class CacheManager(object):
 
             ctypes.windll.kernel32.GetDiskFreeSpaceExW(
                 ctypes.c_wchar_p(path),
-                None, 
-                None, 
+                None,
+                None,
                 ctypes.pointer(available))
 
             return bytes_to_human(available.value, unit)
@@ -328,7 +340,7 @@ class CacheManager(object):
 
             ctypes.windll.kernel32.GetDiskFreeSpaceExW(
                 ctypes.c_wchar_p(path),
-                None, 
+                None,
                 ctypes.pointer(total),
                 None,
                 )
