@@ -7,7 +7,7 @@ try:
 except:
     _DRAW_GRAPHS = False
 
-from ..externals import simplejson as json
+import json
 
 from . import schema
 from .jsonutil import get_column
@@ -83,7 +83,7 @@ class Inspector(object):
         self._intf._get_entry_point()
 
         search_els = self._get_json('%s/search/elements?format=json' % 
-                                        self._intf._entry)
+                                        self._intf._get_entry_point())
 
         if not fields_pattern and ('*' in pattern or '?' in pattern):       
             return get_column(search_els , 'ELEMENT_NAME', pattern)
@@ -101,7 +101,7 @@ class Inspector(object):
         self._intf._get_entry_point()
 
         search_fds = self._get_json('%s/search/elements/%s?format=json'
-                                        % (self._intf._entry, datatype)
+                                        % (self._intf._get_entry_point(), datatype)
                                     )
 
         fields = get_column(search_fds, 'FIELD_ID', pattern)
@@ -206,9 +206,7 @@ class Inspector(object):
             Parameters
             ----------
             datatype: string
-                An experiment type.
-            project: string
-                Optional. Restrict operation to a project.
+                An experiment type. eg: xnat:mrsessiondata
             project: string
                 Optional. Restrict operation to a project.
         """
@@ -237,7 +235,7 @@ class Inspector(object):
             Parameters
             ----------
             datatype: string
-                An experiment type.
+                An experiment type. eg: xnat:mrsessiondata
             project: string
                 Optional. Restrict operation to a project.
         """
@@ -287,12 +285,12 @@ class Inspector(object):
         return self._sub_experiment_values('reconstruction', 
                                            project, experiment_type)
 
-    def architecture(self):
+    def structure(self):
         """ Displays the keywords structure used in XNAT REST API.
         """
         def traverse(coll, lvl):
             for key in schema.resources_tree[coll]:
-                print '%s+%s' % (' ' * lvl, key.upper())
+                print('%s+%s') % (' ' * lvl, key.upper())
 
                 datatypes = set([
                         self._intf._struct[uri]
@@ -301,19 +299,17 @@ class Inspector(object):
                         ])
 
                 if datatypes != set():
-                    print '%s  %s' % (' ' * lvl, '-' * len(key))
+                    print('%s  %s') % (' ' * lvl, '-' * len(key))
 
                 for datatype in datatypes:
-                    print '%s- %s' % (' ' * lvl, datatype)
+                    print('%s- %s') % (' ' * lvl, datatype)
 
                 if schema.resources_tree.has_key(key):
                     traverse(key, lvl + 4)
 
-        print '- %s' % 'PROJECTS'
+        print('- %s') % 'PROJECTS'
         traverse('projects', 4)
 
-    rest_hierarchy = architecture
-
     def _sub_experiment_values(self, sub_exp, project, experiment_type):
         self._intf._get_entry_point()
 
@@ -334,18 +330,8 @@ class Inspector(object):
         return list(set(values))
 
     def _resource_struct(self, name):
-        kbase = {}
-
-        for kfile in glob.iglob('%s/*.struct' % self._intf._cachedir):
-            kdata = json.load(open(kfile, 'rb'))
-            if kdata == {}:
-                continue
-            if name in kdata.keys()[0]:
-                kbase.update(kdata)
-
-        self._intf._struct.update(kbase)
-
-        return kbase
+        
+        return self._intf._struct
     
     def _resource_types(self, name):
         return list(set(self._resource_struct(name).values()))
@@ -503,7 +489,8 @@ class PaintGraph(object):
 
         nx.draw(graph, pos, labels=graph.labels, 
                 node_size=costs, node_color=costs,
-                font_size=13, font_color='orange', font_weight='bold'
+                font_size=13, font_color='orange', 
+                font_weight='bold', with_labels=True
                 )
     
         plt.axis('off')
@@ -569,7 +556,8 @@ class PaintGraph(object):
 
         nx.draw(graph, pos, 
                 node_size=node_size, node_color=node_color,
-                font_size=13, font_color='green', font_weight='bold'
+                font_size=13, font_color='green', font_weight='bold',
+                with_labels=True
                 )
     
         plt.axis('off')
@@ -593,7 +581,8 @@ class PaintGraph(object):
 
         nx.draw(graph, pos, 
                 node_size=costs, node_color=costs,
-                font_size=13, font_color='black', font_weight='bold'
+                font_size=13, font_color='black', 
+                font_weight='bold', with_labels=True
                 )
     
         plt.axis('off')
@@ -666,19 +655,19 @@ class SchemasInspector(object):
         self._intf.manage.schemas._init()
 
         for xsd in self._intf.manage.schemas():
-            print '-'*40
-            print xsd.upper()
-            print '-'*40
+            print('-'*40)
+            print(xsd.upper())
+            print('-'*40)
             print
 
             for datatype in schema.datatypes(
                 self._intf.manage.schemas._trees[xsd]):
-                print '[%s]'%datatype
+                print('[%s]' % datatype)
                 print
 
                 for path in schema.datatype_attributes(
                     self._intf.manage.schemas._trees[xsd], datatype):
-                    print path
+                    print(path)
 
                 print
 
