@@ -1,14 +1,20 @@
 import os
 import time
 import tempfile
-import email
 import getpass
 
-import httplib2
 import json
 
+import requests
+try:
+    import socks
+except ImportError:
+    socks = None
+try:
+    from urlparse import urlparse
+except ImportError:
+    from urllib.parse import urlparse
 from .select import Select
-from .cache import CacheManager, HTCache
 from .help import Inspector, GraphData, PaintGraph, _DRAW_GRAPHS
 from .manage import GlobalManager
 from .uriutil import join_uri, file_path, uri_last
@@ -22,6 +28,7 @@ from . import xpass
 
 DEBUG = False
 
+
 # main entry point
 class Interface(object):
     """ Main entry point to access a XNAT server.
@@ -29,8 +36,7 @@ class Interface(object):
         >>> central = Interface(server='http://central.xnat.org:8080',
                                 user='login',
                                 password='pwd',
-                                cachedir='/tmp'
-                                )
+                                cachedir='/tmp')
 
         Or with config file:
 
@@ -44,7 +50,7 @@ class Interface(object):
             The interactive mode is activated whenever an argument within
             server, user or password is missing. In interactive mode pyxnat
             tries to check the validity of the connection parameters.
-        
+
         Or anonymously (unauthenticated):
 
         >>> central = Interface('http://central.xnat.org', anonymous=True)
@@ -55,17 +61,27 @@ class Interface(object):
             Online or offline mode
         _memtimeout: float
             Lifespan of in-memory cache
+
+        .. note::
+            Proxy support requires the socks module be installed. This can be
+            installed via pip:
+            pip install SocksiPy-branch
+
+        .. note::
+            All caching functionality has been removed from pyxnat as of 1.0.0.0.
+            The cache was causing more hassle than it was worth.
+
     """
 
-    def __init__(self, server=None, user=None, password=None, 
-                 cachedir=tempfile.gettempdir(), config=None, 
-                 anonymous=False):
-        """ 
+    def __init__(self, server=None, user=None, password=None,
+                 cachedir=tempfile.gettempdir(), config=None,
+                 anonymous=False, proxy=None, verify=None):
+        """
             Parameters
             ----------
             server: string | None
                 The server full URL (including port and XNAT instance name
-                if necessary) e.g. http://central.xnat.org, 
+                if necessary) e.g. http://central.xnat.org,
                 http://localhost:8080/xnat_db
                 Or a path to an existing config file. In that case the other
                 parameters (user etc..) are ignored if given.
@@ -76,25 +92,37 @@ class Interface(object):
             password: string | None
                 The user's password.
                 If None the user will be prompted for it.
-            cachedir: string
-                Path of the cache directory (for all queries and 
-                downloaded files)
-                If no path is provided, a platform dependent temp dir is 
-                used.
+            cachedir: string  (Depricated)
+
             config: string
-               Reads a config file in json to get the connection parameters.
-               If a config file is specified, it will be used regardless of
-               other parameters that might have been given.
+                Reads a config file in json to get the connection parameters.
+                If a config file is specified, it will be used regardless of
+                other parameters that might have been given.
             anonymous: boolean
-               Indicates an unauthenticated connection.  If True, user 
-               and password are ignored and a session is started with 
-               no credentials.
+                Indicates an unauthenticated connection.  If True, user
+                and password are ignored and a session is started with
+                no credentials.
+            proxy: string | None
+                Indicates the full URL for an HTTP proxy server to be used for
+                transactions with the specified XNAT server. If you need to
+                specify a username and password for proxy access, prepend them
+                to the hostname:
+                http://user:pass@hostname:port
+
+            verify: True, False, or path to file containing certificate for your site
+              Added to the requests Session, as documented here:
+              http://docs.python-requests.org/en/latest/user/advanced/#ssl-cert-verification
+              Simplifies handling self-certified sites, or sites where there is an issue
+              with certification
+
         """
 
         self._interactive = False
 
         self._anonymous = anonymous
 
+        self._verify = verify
+
         if self._anonymous:
 
             if server is None:
@@ -104,39 +132,35 @@ class Interface(object):
                 self._server = server
                 self._interactive = False
 
+            self.__set_proxy(proxy)
+
             self._user = None
             self._pwd = None
 
-            self._cachedir = os.path.join(
-                cachedir, 'anonymous@%s' % self._server.split('//')[1].replace(
-                        '/', '.').replace(':', '_')
-                )
-        
         else:
 
             if not all([server, user, password]) and not config:
                 self._interactive = True
 
             if all(arg is None
-                   for arg in [server, user, password, config]) \
-                   and os.path.exists(xpass.path()):
+                    for arg in [server, user, password, config]) \
+                    and os.path.exists(xpass.path()):
 
                 connection_args = xpass.read_xnat_pass(xpass.path())
 
                 if connection_args is None:
                     raise Exception('XNAT configuration file not found '
-                                    'or formated incorrectly.')
+                                    'or formatted incorrectly.')
 
                 self._server = connection_args['host']
                 self._user = connection_args['u']
                 self._pwd = connection_args['p']
-                self._cachedir = os.path.join(
-                    cachedir, '%s@%s' % (
-                        self._user, 
-                        self._server.split('//')[1].replace(
-                            '/', '.').replace(':', '_')
-                        )
-                    )
+
+
+                if 'proxy' in connection_args:
+                    self.__set_proxy(connection_args['proxy'])
+                else:
+                    self.__set_proxy(None)
 
             elif config is not None:
                 self.load_config(config)
@@ -156,13 +180,7 @@ class Interface(object):
                 self._user = user
                 self._pwd = password
 
-                self._cachedir = os.path.join(
-                    cachedir, '%s@%s' % (
-                        self._user, 
-                        self._server.split('//')[1].replace(
-                            '/', '.').replace(':', '_')
-                        )
-                    )
+                self.__set_proxy(proxy)
 
         self._callback = None
 
@@ -182,18 +200,14 @@ class Interface(object):
         self.inspect = Inspector(self)
         self.select = Select(self)
         self.array = ArrayData(self)
-        self.cache = CacheManager(self)
+        # self.cache = CacheManager(self)
         self.manage = GlobalManager(self)
         self.xpath = XpathStore(self)
-        
+
         if _DRAW_GRAPHS:
             self._get_graph = GraphData(self)
             self.draw = PaintGraph(self)
 
-        if self._anonymous:
-            response, content = self._http.request(self._server, 'GET')
-            self._jsession = response['set-cookie'][:44]
-
         if self._interactive:
             self._get_entry_point()
 
@@ -201,34 +215,41 @@ class Interface(object):
 
     def __getstate__(self):
         return {
-            '_server': self._server, 
-            '_user': self._user, 
+            '_server': self._server,
+            '_user': self._user,
             '_pwd': self._pwd,
-            '_cachedir': os.path.split(self._cachedir)[0],
             '_anonymous': self._anonymous,
-            }
+        }
 
-    def __setstate__(self, dict):
-        self.__dict__ = dict
+    def __setstate__(self, dictionary):
+        self.__dict__ = dictionary
         if self._anonymous:
             self.__init__(self._server, anonymous=True)
         else:
-            self.__init__(self._server, self._user, self._pwd, self._cachedir)
+            self.__init__(self._server, self._user, self._pwd)
+
+    def __set_proxy(self, proxy=None):
+        if proxy is None:
+            proxy = os.environ.get("http_proxy")
+        if proxy is None:
+            self._proxy_url = None
+        else:
+            self._proxy_url = urlparse(proxy)
 
     def _get_entry_point(self):
         if self._entry is None:
             # /REST for XNAT 1.4, /data if >=1.5
             self._entry = '/REST'
-            try:                
-                self._jsession = 'JSESSIONID=' + self._exec('/data/JSESSION')
+            try:
+                self._jsession = 'JSESSIONID=' + self._exec('/data/JSESSION', force_preemptive_auth=True)
                 self._entry = '/data'
 
                 if is_xnat_error(self._jsession):
                     catch_error(self._jsession)
-            except Exception, e:
+            except Exception as e:
                 if not '/data/JSESSION' in str(e):
                     raise e
-            
+
         return self._entry
 
     def _connect(self, **kwargs):
@@ -246,32 +267,31 @@ class Interface(object):
             self._connect_extras = kwargs
         else:
             kwargs = self._connect_extras
-        
-        kwargs['disable_ssl_certificate_validation'] = True
 
-        if DEBUG:   
-            httplib2.debuglevel = 2
+        self._http = requests.Session()
+
+        # requests verify defaults to True, but can be set from environment variables
+        # Leave as-is unless user has explicitly overridden it
+        if self._verify is not None:
+          self._http.verify = self._verify
 
-        # compatibility with httplib2 < 0.7
-        try:
-            self._http = httplib2.Http(
-                HTCache(self._cachedir, self), 
-                **kwargs
-                )
-        except:
-            del kwargs['disable_ssl_certificate_validation']
-            self._http = httplib2.Http(
-                HTCache(self._cachedir, self), 
-                **kwargs
-                )
-            
         if not self._anonymous:
-            self._http.add_credentials(self._user, self._pwd)
+            self._http.auth = (self._user, self._pwd)
 
-    def _exec(self, uri, method='GET', body=None, headers=None):
+        if self._proxy_url:
+            self._http.proxies = {'http': self._proxy_url.geturl()}
+
+
+        # Turns out this doesn't work any more: XNAT doesn't do the 401 response that forces
+        # httplib2 to re-submit the request with credentials. See where the Authorization header
+        # is added manually in the _exec function.
+        # if not self._anonymous:
+        #    self._http.add_credentials(self._user, self._pwd)
+
+    def _exec(self, uri, method='GET', body=None, headers=None, force_preemptive_auth=False, **kwargs):
         """ A wrapper around a simple httplib2.request call that:
                 - avoids repeating the server url in the request
-                - deals with custom caching mechanisms
+                - deals with custom caching mechanisms :: Depricated
                 - manages a user session with cookies
                 - catches and broadcast specific XNAT errors
 
@@ -279,12 +299,28 @@ class Interface(object):
             ----------
             uri: string
                 URI of the resource to be accessed. e.g. /REST/projects
-            method: GET | PUT | POST | DELETE
+            method: GET | PUT | POST | DELETE | HEAD
                 HTTP method.
-            body: string
+            body: string | dict
                 HTTP message body
             headers: dict
                 Additional headers for the HTTP request.
+            force_preemptive_auth: boolean
+                .. note:: Depricated as of 1.0.0.0
+                Indicates whether the request should include an Authorization header with basic auth credentials.
+            **kwargs: dictionary
+                Additional parameters to pass directly to the Requests HTTP call.
+
+            HTTP:GET
+            ----------
+                When calling with GET as method, the body parameter can be a key:value dictionary containing
+                request parameters or a string of parameters. They will be url encoded and appended to the url.
+
+            HTTP:POST
+            ----------
+                When calling with POST as method, the body parameter can be a key:value dictionary containing
+                request parameters they will be url encoded and appended to the url.
+
         """
 
         if headers is None:
@@ -295,94 +331,43 @@ class Interface(object):
         uri = join_uri(self._server, uri)
 
         if DEBUG:
-            print uri
-        # using session authentication
-        headers['cookie'] = self._jsession
-        headers['connection'] = 'keep-alive'
+            print(uri)
 
-        # reset the memcache when client changes something on the server
-        if method in ['PUT', 'DELETE']:
-            self._memcache = {}
-        
-        if self._mode == 'online' and method == 'GET':
+        response = None
 
-            if time.time() - self._memcache.get(uri, 0) < self._memtimeout:
-                if DEBUG:
-                    print 'send: GET CACHE %s' % uri
-
-                info, content = self._http.cache.get(uri
-                                                     ).split('\r\n\r\n', 1)
-
-                self._memcache[uri] = time.time()
-                response = None
-            else:
-                response, content = self._http.request(uri, method, 
-                                                       body, headers)
-                self._memcache[uri] = time.time()
-
-        elif self._mode == 'offline' and method == 'GET':
-
-            cached_value = self._http.cache.get(uri)
-
-            if cached_value is not None:
-                if DEBUG:
-                    print 'send: GET CACHE %s' % uri
-                info, content = cached_value.split('\r\n\r\n', 1)
-                response = None
-            else:
-                try:
-                    self._http.timeout = 10
-
-                    response, content = self._http.request(uri, method, 
-                                                           body, headers)
-
-                    self._http.timeout = None
-                    self._memcache[uri] = time.time()
-                except Exception, e:
-                    catch_error(e)
+        if method is 'PUT':
+            response = self._http.put(uri, headers=headers, data=body, **kwargs)
+        elif method is 'GET':
+            response = self._http.get(uri, headers=headers, params=body, **kwargs)
+        elif method is 'POST':
+            response = self._http.post(uri, headers=headers, data=body, **kwargs)
+        elif method is 'DELETE':
+            response = self._http.delete(uri, headers=headers, data=body, **kwargs)
+        elif method is 'HEAD':
+            response = self._http.head(uri, headers=headers, data=body, **kwargs)
         else:
-            response, content = self._http.request(uri, method, 
-                                                   body, headers)
+            print 'unsupported HTTP method'
+            return
 
-        if DEBUG:
-            if response is None:
-                response = httplib2.Response(email.message_from_string(info))
-                print 'reply: %s %s from cache' % (response.status, 
-                                                   response.reason
-                                                   )
-                for key in response.keys():
-                    print 'header: %s: %s' % (key.title(), response.get(key))
+        if (response is not None and not response.ok) or is_xnat_error(response.content):
+            if DEBUG:
+                print(response.keys())
+                print(response.get("status"))
 
-        if response is not None and response.has_key('set-cookie'):
-            self._jsession = response.get('set-cookie')[:44]
-
-        if response is not None and response.get('status') == '404':
-            r,_ = self._http.request(self._server)
-
-            if self._server.rstrip('/') != r.get('content-location', 
-                                                 self._server).rstrip('/'):
-                
-                old_server = self._server
-                self._server = r.get('content-location').rstrip('/')
-                return self._exec(uri.replace(old_server, ''), method, body)
-            else:
-                raise httplib2.HttpLib2Error('%s %s %s' % (uri, 
-                                                           response.status,
-                                                           response.reason
-                                                           )
-                                             )
-
-        if is_xnat_error(content):
-            catch_error(content)
-
-        return content
+            catch_error(response.content, '''pyxnat._exec failure:
+    URI: {response.url}
+    status code: {response.status_code}
+    headers: {response.headers}
+    content: {response.content}
+'''.format(response=response))
 
+        return response.content
 
     def _get_json(self, uri):
         """ Specific Interface._exec method to retrieve data.
-            It forces the data format to csv and then puts it back to a 
+            It forces the data format to csv and then puts it back to a
             json-like format.
-            
+
             Parameters
             ----------
             uri: string
@@ -401,7 +386,7 @@ class Interface(object):
                 uri += '?format=csv'
 
         content = self._exec(uri, 'GET')
-        
+
         if is_xnat_error(content):
             catch_error(content)
 
@@ -416,30 +401,15 @@ class Interface(object):
 
     def _get_head(self, uri):
         if DEBUG:
-            print 'GET HEAD'
-        _nocache = httplib2.Http(**self._connect_extras)
-        if self._user:
-            _nocache.add_credentials(self._user, self._pwd)
+            print('GET HEAD')
 
-        rheaders = {'cookie':self._jsession}
+        response = self._http.head('{server}{uri}'.format(server=self._server, uri=uri))
 
-        try:
-            head = _nocache.request(
-                '%s%s' % (self._server, uri), 'HEAD', headers=rheaders)[0]
-        except:
+        if not response.ok:
             time.sleep(1)
-            head = _nocache.request(
-                '%s%s' % (self._server, uri), 'HEAD', headers=rheaders)[0]
+            self._http.head('{server}{uri}'.format(server=self._server, uri=uri))
 
-        info = email.Message.Message()
-
-        for key, value in head.iteritems():
-            if key == 'content-disposition':
-                info['content-location'] = '%s%s' % (self._server, uri)
-            if key not in ['set-cookie']:
-                info[key] = value
-
-        return info
+        return response.headers
 
     def save_config(self, location):
         """ Saves current configuration - including password - in a file.
@@ -449,7 +419,7 @@ class Interface(object):
                 is saved at a safe location with appropriate permissions.
 
             .. note::
-                This method raises NotImplementedError for an anonymous 
+                This method raises NotImplementedError for an anonymous
                 interface.
 
             Parameters
@@ -458,18 +428,19 @@ class Interface(object):
                 Destination config file.
         """
         if self._anonymous:
-            raise NotImplementedError, \
-                  'no save_config() for anonymous interfaces'
+            raise NotImplementedError(
+                'no save_config() for anonymous interfaces')
 
         if not os.path.exists(os.path.dirname(location)):
             os.makedirs(os.path.dirname(location))
 
         fp = open(location, 'w')
-        config = {'server':self._server, 
-                  'user':self._user, 
-                  'password':self._pwd,
-                  'cachedir':os.path.split(self._cachedir)[0],
+        config = {'server': self._server,
+                  'user': self._user,
+                  'password': self._pwd,
                   }
+        if self._proxy_url:
+            config['proxy'] = self._proxy_url.geturl()
 
         json.dump(config, fp)
         fp.close()
@@ -479,7 +450,7 @@ class Interface(object):
             parameters.
 
             .. note::
-                This method raises NotImplementedError for an anonymous 
+                This method raises NotImplementedError for an anonymous
                 interface.
 
             Parameters
@@ -488,8 +459,8 @@ class Interface(object):
                 Configuration file path.
         """
         if self._anonymous:
-            raise NotImplementedError, \
-                  'no load_config() for anonymous interfaces'
+            raise NotImplementedError(
+                'no load_config() for anonymous interfaces')
 
         if os.path.exists(location):
             fp = open(location, 'rb')
@@ -499,20 +470,69 @@ class Interface(object):
             self._server = str(config['server'])
             self._user = str(config['user'])
             self._pwd = str(config['password'])
-            self._cachedir = str(config['cachedir'])
 
-            self._cachedir = os.path.join(
-                self._cachedir, '%s@%s' % (
-                    self._user, 
-                    self._server.split('//')[1].replace(
-                        '/', '.').replace(':', '_')
-                    )
-                )
+            if 'proxy' in config:
+                self.__set_proxy(str(config['proxy']))
+            else:
+                self.__set_proxy(None)
+
         else:
-            raise Exception('Configuration file does not exists.')
+            raise Exception('Configuration file does not exist.')
 
     def version(self):
         return self._exec('/data/version')
 
     def set_logging(self, level=0):
         pass
+
+    def disconnect(self):
+        """
+            Tell XNAT to disconnect this session
+        """
+        self._exec('/data/JSESSION', method='DELETE')
+        pass
+
+    def get(self, uri, **kwargs):
+        '''
+        Wrapper around requests.get()
+        returns rquests.response object
+        '''
+        uri = join_uri(self._server, uri)
+        response = self._http.get(uri, **kwargs)
+        return response
+
+    def put(self, uri, **kwargs):
+        '''
+        Wrapper around requests.put()
+        returns rquests.response object
+        '''
+        uri = join_uri(self._server, uri)
+        response = self._http.put(uri, **kwargs)
+        return response
+
+    def post(self, uri, **kwargs):
+        '''
+        Wrapper around requests.post()
+        returns rquests.response object
+        '''
+        uri = join_uri(self._server, uri)
+        response = self._http.post(uri, **kwargs)
+        return response
+
+    def delete(self, uri, **kwargs):
+        '''
+        Wrapper around requests.delete()
+        returns rquests.response object
+        '''
+        uri = join_uri(self._server, uri)
+        response = self._http.delete(uri, **kwargs)
+        return response
+
+    def head(self, uri, **kwargs):
+        '''
+        Wrapper around requests.head()
+        returns rquests.response object
+        '''
+        uri = join_uri(self._server, uri)
+        response = self._http.head(uri, **kwargs)
+        return response
