@@ -1,9 +1,12 @@
 import csv
 import copy
 from fnmatch import fnmatch
-from StringIO import StringIO
+try:
+    from StringIO import StringIO
+except ImportError:
+    from io import StringIO
 
-from ..externals import simplejson as json
+import json
 
 # jdata is a list of dicts
 
@@ -111,21 +114,32 @@ class JsonTable(object):
         self.order_by = order_by
 
     def __repr__(self):
-        if len(self.data) == 0:
-            return '[]'
-        elif len(self.data) == 1:
-            return str(self.data[0])
+        # if len(self.data) == 0:
+        #     return '[]'
+        # elif len(self.data) == 1:
+        #     return str(self.data[0])
         
-        return ('[%s\n .\n .\n . \n%s]\n\n'
-                '------------\n'
-                '%s rows\n'
-                '%s columns\n'
-                '%s characters') % (str(self.data[0]), 
-                                    str(self.data[-1]),
-                                    len(self), 
-                                    len(self.headers()),
-                                    len(self.dumps_csv()) 
-                                    )
+        if len(self.headers()) <= 5:
+            _headers = ','.join(self.headers())
+        else:
+            _headers = '%s ... %s' % (','.join(self.headers()[:2]), 
+                                      ','.join(self.headers()[-2:])
+                                      )
+
+        return '<JsonTable %s:%s> %s' % (
+            len(self.data), len(self.headers()), _headers
+            )
+    
+        # return ('[%s\n .\n .\n . \n%s]\n\n'
+        #         '------------\n'
+        #         '%s rows\n'
+        #         '%s columns\n'
+        #         '%s characters') % (str(self.data[0]), 
+        #                             str(self.data[-1]),
+        #                             len(self), 
+        #                             len(self.headers()),
+        #                             len(self.dumps_csv()) 
+        #                             )
 
     def __str__(self):
         return self.dumps_csv()
@@ -163,6 +177,9 @@ class JsonTable(object):
             self.order_by
             )
 
+    def has_header(self, name):
+        return name in self.headers()
+
     def headers(self):
         """ Returns the headers of the object.
         """
