@@ -8,7 +8,7 @@ from .. import Interface
 
 _modulepath = os.path.dirname(os.path.abspath(__file__))
 
-central = Interface('https://central.xnat.org', 'nosetests', 'nosetests')
+central = Interface(config=os.path.join(os.path.dirname(os.path.abspath(__file__)), 'central.cfg'))
 
 _id_set1 = {
     'sid':uuid1().hex,
@@ -144,8 +144,6 @@ def test_put_file():
 def test_get_file():
     fh = subj_1.resource('test').file('hello.txt')
 
-    central.cache.set_usage(expiration=0)
-
     fpath = fh.get()
     assert os.path.exists(fpath)
     assert open(fpath, 'rb').read() == 'Hello XNAT!\n'
@@ -153,11 +151,9 @@ def test_get_file():
     custom = os.path.join(tempfile.gettempdir(), uuid1().hex)
     
     fh.get(custom)
-    assert os.path.exists(custom)
-    assert not os.path.exists(fpath)
-    fh.get()
-    assert os.path.exists(custom)
+    assert os.path.exists(custom), "fpath: %s custom: %s" % (fpath, custom)
     os.remove(custom)
+    os.remove(fpath)
 
 def test_put_dir_file():
     local_path = os.path.join(_modulepath, 'hello_again.txt')
@@ -169,8 +165,6 @@ def test_put_dir_file():
 def test_get_dir_file():
     fh = subj_1.resource('test').file('dir/hello.txt')
 
-    central.cache.set_usage(expiration=0)
-
     fpath = fh.get()
     assert os.path.exists(fpath)
     assert open(fpath, 'rb').read() == 'Hello again!\n'
@@ -178,11 +172,9 @@ def test_get_dir_file():
     custom = os.path.join(tempfile.gettempdir(), uuid1().hex)
     
     fh.get(custom)
-    assert os.path.exists(custom)
-    assert not os.path.exists(fpath)
-    fh.get()
-    assert os.path.exists(custom)
+    assert os.path.exists(custom), "fpath: %s custom: %s" % (fpath, custom)
     os.remove(custom)
+    os.remove(fpath)
 
 def test_get_copy_file():
     fpath = os.path.join(tempfile.gettempdir(), uuid1().hex)
@@ -193,7 +185,6 @@ def test_get_copy_file():
     fd.close()
     os.remove(fpath)
 
-    central.cache.set_usage(expiration=1)
 
 def test_file_last_modified():
     f = subj_1.resource('test').file('hello.txt')
@@ -210,6 +201,31 @@ def test_last_modified():
 
     assert t1 != t2
 
+def test_getitem_key():
+    projects = central.select.projects()
+    assert projects.first().id() == projects[0].id()
+    piter = projects.__iter__()
+    next(piter)
+    assert next(piter).id() == projects[1].id()
+
+def test_getitem_slice():
+    projects = central.select.projects()
+    assert projects.first().id() == next(projects[:1]).id()
+    piter = projects.__iter__()
+    next(piter)
+    next(piter)
+    next(piter)
+    for pobj in projects[3:6]:
+        assert next(piter).id() == pobj.id()
+
+def test_subject1_parent():
+    project = central.select.project('nosetests')
+    assert subj_1.parent()._uri == project._uri
+
+def test_project_parent():
+    project = central.select.project('nosetests')
+    assert not project.parent()
+
 def test_subject1_delete():
     assert subj_1.exists()
     subj_1.delete()
@@ -224,11 +240,40 @@ def test_subject2_delete():
 def test_project_configuration():
     project = central.select('/project/nosetests')
     assert project.quarantine_code() == 0
-    assert project.prearchive_code() == 0
+    assert project.prearchive_code() == 4, project.prearchive_code()
     assert project.current_arc() == 'arc001'
     assert 'nosetests' in project.users()
     assert 'nosetests' in project.owners()
-    assert project.user_role('nosetests') == 'owner'
-    
+    assert project.user_role('nosetests') == 'owner'                              
+                                              
+def test_put_zip():
+    local_path = os.path.join(_modulepath, 'hello_dir.zip')
+    assert os.path.exists(local_path)
 
-    
+    # Upload and confirm proper extraction
+    r1 = subj_1.resource('test_zip_extract')
+    r1.put_zip(local_path, extract=True)
+    assert r1.exists()
+    assert r1.file('hello_dir/hello_xnat_dir.txt').exists()
+    assert r1.file('hello_dir/hello_dir2/hello_xnat_dir2.txt').exists()
+   
+    # Upload and confirm not extracted 
+    r2 = subj_1.resource('test_zip_no_extract')
+    r2.put_zip(local_path, extract=False)
+    assert r2.exists()
+    assert r2.file('hello_dir.zip').exists()
+                                                                                                
+def test_get_zip():
+    r = subj_1.resource('test_zip_extract')
+    local_dir = os.path.join(_modulepath, 'test_zip_download'+r.id())
+    file_list = [os.path.join(local_dir,'test_zip_extract/hello_dir'), 
+                 os.path.join(local_dir,'test_zip_extract/hello_dir/hello_xnat_dir.txt'),
+                 os.path.join(local_dir,'test_zip_extract/hello_dir/hello_dir2'),
+                 os.path.join(local_dir,'test_zip_extract/hello_dir/hello_dir2/hello_xnat_dir2.txt')]
+
+    if not os.path.exists(local_dir):
+        os.mkdir(local_dir)
+        
+    r.get(local_dir, extract=True)
+    for f in file_list:
+        assert os.path.exists(f)
